
/*
 * Copyright (C) 2004-2005 Maximilian Schwerin
 *
 * This file is part of oxine a free media player.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $Id: filelist_menu.h 1238 2006-10-05 13:14:03Z mschwerin $
 *
 */

#ifndef HAVE_FILELIST_MENU_H
#define HAVE_FILELIST_MENU_H
#ifdef __cplusplus
extern "C" {
#endif

#include "oxine.h"

int filelist_menu_is_current_menu (oxine_t * oxine);

void show_music_menu_cb (void *oxine_p);
void show_video_menu_cb (void *oxine_p);
void show_media_menu_cb (void *oxine_p);

void show_filelist_menu_cb (void *oxine_p);

void enter_music_menu_cb (void *oxine_p);
void enter_video_menu_cb (void *oxine_p);
void enter_media_menu_cb (void *oxine_p);

void filelist_menu_free (void);

#ifdef __cplusplus
}
#endif
#endif /* HAVE_FILELIST_MENU_H */
